@@ -260,6 +260,7 @@ gboolean              exo_icon_view_path_is_selected          (const ExoIconView
 GList                *exo_icon_view_get_selected_items        (const ExoIconView        *icon_view);
 void                  exo_icon_view_select_all                (ExoIconView              *icon_view);
 void                  exo_icon_view_unselect_all              (ExoIconView              *icon_view);
+void                  exo_icon_view_selection_invert          (ExoIconView              *icon_view);
 void                  exo_icon_view_item_activated            (ExoIconView              *icon_view,
                                                                GtkTreePath              *path);
 
@@ -311,8 +312,13 @@ gboolean              exo_icon_view_get_dest_item_at_pos      (ExoIconView
                                                                gint                      drag_y,
                                                                GtkTreePath             **path,
                                                                ExoIconViewDropPosition  *pos);
+#if GTK_CHECK_VERSION (3, 0, 0)
+cairo_surface_t      *exo_icon_view_create_drag_icon          (ExoIconView              *icon_view,
+                                                               GtkTreePath              *path);
+#else
 GdkPixmap            *exo_icon_view_create_drag_icon          (ExoIconView              *icon_view,
                                                                GtkTreePath              *path);
+#endif
 
 
 /* Interactive search support */
