@@ -14,10 +14,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -310,7 +310,7 @@ exo_toolbars_editor_drag_data_get (GtkWidget          *item,
 
   action = g_object_get_data (G_OBJECT (item), I_("gtk-action"));
   target = (action != NULL) ? gtk_action_get_name (action) : "separator";
-  gtk_selection_data_set (selection_data, selection_data->target,
+  gtk_selection_data_set (selection_data, gtk_selection_data_get_target (selection_data),
                           8, (const guchar *) target, strlen (target));
 }
 
@@ -322,17 +322,16 @@ event_box_realize (GtkWidget *widget,
 {
   GtkImageType type;
   GdkPixbuf   *pixbuf;
-  gchar       *stock_id;
+  const gchar *icon_name;
 
   _exo_toolbars_set_drag_cursor (widget);
 
   type = gtk_image_get_storage_type (image);
-  if (type == GTK_IMAGE_STOCK)
+  if (type == GTK_IMAGE_ICON_NAME)
     {
-      gtk_image_get_stock (image, &stock_id, NULL);
-      pixbuf = gtk_widget_render_icon (widget, stock_id, GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
-      if (G_LIKELY (pixbuf != NULL))
-        gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
+      gtk_image_get_icon_name (image, &icon_name, NULL);
+      if (icon_name != NULL)
+        gtk_drag_source_set_icon_name (widget, icon_name);
     }
   else if (type == GTK_IMAGE_PIXBUF)
     {
@@ -516,7 +515,7 @@ exo_toolbars_editor_update (ExoToolbarsEditor *editor)
       if (G_UNLIKELY (stock == NULL))
         stock = g_strdup (GTK_STOCK_DND);
 
-      image = gtk_image_new_from_stock (stock, GTK_ICON_SIZE_LARGE_TOOLBAR);
+      image = gtk_image_new_from_icon_name (stock, GTK_ICON_SIZE_LARGE_TOOLBAR);
       item = exo_toolbars_editor_create_item (editor, image, text,
                                               GDK_ACTION_MOVE);
       g_object_set_data (G_OBJECT (item), I_("gtk-action"), action);
